<?php

namespace Drupal\uvf_migrate\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class CustomForm.
 */
class UvfMigrateImportForm extends FormBase
{
    /**
     * {@inheritdoc}
     */
    public function getFormId()
    {
        return 'uvf_migrate_import_form';
    }

    /**
     * {@inheritdoc}
     */
    public function buildForm(array $form, FormStateInterface $form_state)
    {
        $default_scheme = $this->config('system.file')->get('default_scheme');

        $form['upload_fid'] = [
            '#type' => 'managed_file',
            '#upload_loction' => "{$default_scheme}://import/zip",
            '#upload_validators' => [
                'file_validate_extensions' => ['zip yml'],
            ],
            '#title' => $this->t('Upload a file with content to import'),
            '#description' => $this->t(
                'Upload a Zip or YAML file with the previously exported content.'
            ),
        ];
        $form['submit'] = [
            '#type' => 'submit',
            '#value' => $this->t('Submit'),
        ];

        return $form;
    }

    /**
     * {@inheritdoc}
     */
    public function validateForm(array &$form, FormStateInterface $form_state)
    {
        $upload_file = $form_state->getValue('upload_fid');

        if (!$upload_file) {
            $form_state->setErrorByName(
                'upload_fid',
                $this->t('Please upload to import your content.')
            );
        }
    }

    /**
     * {@inheritdoc}
     */
    public function submitForm(array &$form, FormStateInterface $form_state)
    {
       
    }
}
