<?php

 /**
 * @file
 * Migration src file for Article.
 *
 * This module migrates data of Article type.
 */

namespace Drupal\uvf_migrate\Plugin\migrate\source;

use Drupal\migrate\Plugin\migrate\source\SqlBase;
use Drupal\migrate\Row;

/**
* Source plugin for the article.
*
* @MigrateSource(
*   id = "article"
* )
*/
class Article extends SqlBase
{
    /**
     * {@inheritdoc}
     */
    public function query()
    {
        $query = $this->select('custom_news', 'cn')
            ->fields('cn', ['nid','title','body','field_publish_date']);
        return $query;
    }

    /**
     * {@inheritdoc}
     */
    public function fields()
    {
        $fields = [
            'nid' => $this->t('nid'),
            'title' => $this->t('title'),
            'body' => $this->t('body'),
            'field_publish_date' => $this->t('field_publish_date')
        ];

        return $fields;
    }

    /**
     * {@inheritdoc}
     */
    public function getIds()
    {
        return [
            'nid' => [
                'type' => 'integer',
                'alias' => 'cn',
            ],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function prepareRow(Row $row)
    {
        $publish_date = $row->getSourceProperty('publish_date');
        $new_date = date('Y-m-d\Th:i:s', strtotime($publish_date));
        $row->setSourceProperty('publish_date', $new_date);
        return parent::prepareRow($row);
    }
}
